
local MAJOR = "StarLibSpecialChar-1.0" 
local MINOR = 13
assert(LibStub, MAJOR.." requires LibStub") 
local LibSpecialChar = LibStub:NewLibrary(MAJOR, MINOR)
if not LibSpecialChar then return end
local LibError = LibStub("StarLibError-1.0")
assert(LibError, MAJOR .. " requires StarLibError-1.0")
local LibUtils = LibStub("StarLibUtils-1.0")
assert(LibUtils, MAJOR .. " requires StarLibUtils-1.0")

local pool = setmetatable({}, {__mode = "k"})

if not LibSpecialChar.__index then
	LibSpecialChar.__index = LibSpecialChar
end


-- @name StarLibSpecialChar:New
-- @usage StarLibSpecialChar:New(duration, repeating, callback, data)
-- @param duration How long the timer should be in milliseconds.
-- @param repeating Whether to repeat the timer or not
-- @param callback Function to call when the timer has expired
-- @param data Data to pass to the callback
-- @param errorLevel Error verbosity level
-- @param durationLimit How much to throttle the timer. Be nice. 10 milliseconds is default.
-- @return A new StarLibSpecialChar object
function LibSpecialChar:New(duration, repeating, callback, data, errorLevel, durationLimit)
	
	local obj = next(pool)

	if obj then
		pool[obj] = nil
	else
		obj = {}
	end

	setmetatable(obj, self)
	
	obj.error = LibError:New(MAJOR, errorLevel)
	return obj	
	
end

-- @name StarLibSpecialChar:Del
-- @usage StarLibSpecialChar:Del([timer]) or object:Del()
-- @param timer An optional timer object
-- @return Nothing
function LibSpecialChar:Del(timer)
	if type(timer) ~= "table" then timer = self end
	timer.error:Del()
	pool[timer] = true
end
